@@ -14,7 +14,7 @@ use crate::{Directive, StringValue};
 /// use apollo_encoder::{Argument, Directive, EnumValue, Value};
 ///
 /// let mut enum_ty = EnumValue::new("CARDBOARD_BOX".to_string());
-/// enum_ty.description(Some("Box nap spot.".to_string()));
+/// enum_ty.description("Box nap spot.".to_string());
 /// let mut deprecated_directive = Directive::new(String::from("deprecated"));
 /// deprecated_directive.arg(Argument::new(
 ///     String::from("reason"),
@@ -35,7 +35,7 @@ pub struct EnumValue {
     // Name must return a String.
     name: String,
     // Description may return a String or null.
-    description: StringValue,
+    description: Option<StringValue>,
     /// The vector of directives
     directives: Vec<Directive>,
 }
@@ -45,16 +45,16 @@ impl EnumValue {
     pub fn new(name: String) -> Self {
         Self {
             name,
-            description: StringValue::Field { source: None },
+            description: None,
             directives: Vec::new(),
         }
     }
 
     /// Set the Enum Value's description.
-    pub fn description(&mut self, description: Option<String>) {
-        self.description = StringValue::Field {
+    pub fn description(&mut self, description: String) {
+        self.description = Some(StringValue::Field {
             source: description,
-        };
+        });
     }
 
     /// Add a directive.
@@ -65,7 +65,9 @@ impl EnumValue {
 
 impl fmt::Display for EnumValue {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self.description)?;
+        if let Some(description) = &self.description {
+            write!(f, "{}", description)?;
+        }
         write!(f, "  {}", self.name)?;
 
         for directive in &self.directives {
@@ -92,7 +94,7 @@ mod tests {
     #[test]
     fn it_encodes_an_enum_value_with_desciption() {
         let mut enum_ty = EnumValue::new("CAT_TREE".to_string());
-        enum_ty.description(Some("Top bunk of a cat tree.".to_string()));
+        enum_ty.description("Top bunk of a cat tree.".to_string());
         assert_eq!(
             enum_ty.to_string(),
             r#"  "Top bunk of a cat tree."
@@ -108,7 +110,7 @@ mod tests {
             String::from("first"),
             Value::List(vec![Value::Int(1), Value::Int(2)]),
         ));
-        enum_ty.description(Some("Box nap\nspot.".to_string()));
+        enum_ty.description("Box nap\nspot.".to_string());
         enum_ty.directive(directive);
 
         assert_eq!(
@@ -124,7 +126,7 @@ mod tests {
     #[test]
     fn it_encodes_an_enum_value_with_deprecated_block_string_value() {
         let mut enum_ty = EnumValue::new("CARDBOARD_BOX".to_string());
-        enum_ty.description(Some("Box nap\nspot.".to_string()));
+        enum_ty.description("Box nap\nspot.".to_string());
         let mut deprecated_directive = Directive::new(String::from("deprecated"));
         deprecated_directive.arg(Argument::new(
             String::from("reason"),
